<?php

namespace Drupal\acquia_contenthub;

use Drupal\acquia_contenthub\Encoder\ContentHubCdfEncoderD10;
use Drupal\acquia_contenthub\Normalizer\NormalizerWrapperD10;
use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;

/**
 * Make sure it exposes the acquia_contenthub_cdf format as json.
 *
 * Alters the service definition for RemovePageThemeWrapperSubscriber.
 */
class AcquiaContentHubServiceProvider extends ServiceProviderBase {

  /**
   * {@inheritdoc}
   */
  public function alter(ContainerBuilder $container) {
    if ($container->has('http_middleware.negotiation') && is_a($container->getDefinition('http_middleware.negotiation')->getClass(), '\Drupal\Core\StackMiddleware\NegotiationMiddleware', TRUE)) {
      $container
        ->getDefinition('http_middleware.negotiation')
        ->addMethodCall('registerFormat',
          [
            'acquia_contenthub_cdf',
            ['application/json'],
          ]
        );
    }
    if (str_starts_with(\Drupal::VERSION, 10)) {
      $normalizer_wrapper = $container->getDefinition('serializer.normalizer.acquia_contenthub_cdf.acquia_contenthub');
      $normalizer_wrapper->setClass(NormalizerWrapperD10::class);
      $cdf_encoder = $container->getDefinition('serializer.encoder.acquia_contenthub_cdf.acquia_contenthub');
      $cdf_encoder->setClass(ContentHubCdfEncoderD10::class);
    }
  }

}
