<?php

namespace Drupal\Tests\acquia_contenthub\Functional;

/**
 * Create a block and test block markup by attempting to view the altered block.
 *
 * @group acquia_contenthub_no_test
 * @group orca_ignore
 */
class BlockContentTypeHooksTest extends BlockContentTypeTest {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'classy';

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'block',
    'block_content',
    'acquia_contenthub',
    'ch_block_content_test',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    $this->markTestSkipped('Skipped until LCH-5682 is resolved.');
    parent::setUp();
  }

  /**
   * Checks the acquia-contenthub block hooks functionality.
   */
  public function testBlockContentView() {
    $this->drupalLogin($this->adminUser);
    $block = $this->createBlockContent();
    $block->set('body', 'block_body_value');
    $block->save();

    // Attempt to view the block.
    $this->drupalGet('acquia-contenthub/display/block_content/' . $block->id() . '/default');

    $this->assertSession()->statusCodeEquals(200);

    $this->assertSession()->responseContains($block->get('body')->getString());

    $this->assertSession()->responseNotContains($block->label());

    $this->removeWhiteSpace();

    $expected = <<<HTML
</head><body><div class="clearfix text-formatted field field--name-body field--type-text-with-summary field--label-hidden field__item"><p>block_body_value</p></div>
      [hook_block_content_view][hook_block_content_view_alter]



    <div data-content-barrier-exclude="true"></div></body></html>
HTML;
    $this->assertSession()->responseContains($expected);
    $this->assertOffCanvasWrapperRemoved();
  }

}
