<?php

namespace Drupal\Tests\acquia_contenthub\Functional;

use Drupal\Tests\block_content\Functional\BlockContentTestBase;

/**
 * Create a block and test block markup by attempting to view the block.
 *
 * @group acquia_contenthub_no_test
 * @group orca_ignore
 */
class BlockContentTypeTest extends BlockContentTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'classy';

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'block',
    'block_content',
    'acquia_contenthub',
  ];

  /**
   * Permissions to grant admin user.
   *
   * @var array
   */
  protected $permissions = [
    'administer blocks',
    'administer acquia content hub',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    $this->markTestSkipped('Skipped until LCH-5682 is resolved.');
    parent::setUp();
  }

  /**
   * Checks the acquia-contenthub block view functionality.
   */
  public function testBlockContentView() {
    $this->drupalLogin($this->adminUser);
    $block = $this->createBlockContent();
    $block->set('body', 'block_body_value');
    $block->save();

    // Attempt to view the block.
    $this->drupalGet('acquia-contenthub/display/block_content/' . $block->id() . '/default');

    $this->assertSession()->statusCodeEquals(200);

    $this->assertSession()->responseContains($block->get('body')->getString());

    $this->assertSession()->responseNotContains($block->label());

    $this->removeWhiteSpace();

    $expected = '</head><body><div class="clearfix text-formatted field field--name-body field--type-text-with-summary field--label-hidden field__item"><p>block_body_value</p></div><div data-content-barrier-exclude="true"></div></body></html>';
    $this->assertSession()->responseContains($expected);
    $this->assertOffCanvasWrapperRemoved();
  }

  /**
   * Assert that off-canvas wrapper has been removed.
   */
  protected function assertOffCanvasWrapperRemoved() {
    $this->assertSession()->responseNotContains('dialog-off-canvas-main-canvas');
    $this->assertSession()->responseNotContains('data-off-canvas-main-canvas');
  }

}
