<?php

namespace Drupal\Tests\acquia_contenthub\Functional;

use Drupal\Component\Serialization\Json;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Test that Acquia Content Hub produces a correct Media Entity CDF.
 *
 * @group acquia_contenthub_no_test
 * @group orca_ignore
 */
class MediaEntityImageTest extends ContentHubTestBase {

  use StringTranslationTrait;

  /**
   * Admin role.
   *
   * @var string
   */
  protected $adminRole;

  /**
   * The permissions of the admin user.
   *
   * @var string[]
   */
  protected $adminUserPermissions = [
    'administer acquia content hub',
    'access administration pages',
    'view media',
    'create media',
    'update media',
    'update any media',
    'delete media',
    'delete any media',
    'access media overview',
  ];

  /**
   * Modules to enable for this test.
   *
   * @var string[]
   */
  public static $modules = [
    'acquia_contenthub',
    'user',
    'entity',
    'media_entity',
    'entity_browser',
    'media_entity_image',
    'media_entity_image_ch',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    $this->markTestSkipped('Skipped until LCH-5683 is resolved.');
    parent::setUp();
    // Create the users used for the tests.
    $this->adminRole = $this->createAdminRole('administrator', 'Administrator');
    $this->adminUser = $this->drupalCreateUser($this->adminUserPermissions);
  }

  /**
   * Tests a Media entity CDF.
   */
  public function testMediaEntityImage() {
    $this->drupalLogin($this->adminUser);

    // Create the Image Media Entity.
    $this->drupalGet('media/add/image');
    $this->assertSession()->statusCodeEquals(200);
    $edit = [
      'name[0][value]' => 'Media Test',
    ];
    $this->submitForm($edit, $this->t('Save and publish'));
    $this->configureContentHubContentTypes('media', ['image']);
    $this->setRoleFor($this->adminRole);

    // Render CDF as admin to avoid having to set permissions for media entity.
    $output = $this->drupalGetCdf('acquia-contenthub-cdf/media/1', [
      'query' => [
        'include_references' => 'true',
      ],
    ]);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertEquals('array<string>', $output['entities']['0']['attributes']['bundle']['type']);
    $this->assertEquals('image', $output['entities']['0']['attributes']['bundle']['value']['en'][0]);
    $this->assertEquals('Media Test', $output['entities']['0']['attributes']['name']['value']['en'][0]);
    $this->assertNotNull($output['entities']['0']['assets'][0]['url']);
    $this->assertNotNull($output['entities']['0']['assets'][0]['replace-token']);
    $thumbnail = $output['entities']['0']['attributes']['thumbnail']['value']['en'][0];
    $thumbnail = Json::decode($thumbnail);
    $this->assertEquals('Media Test', $thumbnail['title']);
  }

}
